Struct OrtAllocator

#[repr(C)]
pub struct OrtAllocator { pub version: u32, pub Alloc: Option<unsafe extern "C" fn(this_: *mut OrtAllocator, size: usize) -> *mut c_void>, pub Free: Option<unsafe extern "C" fn(this_: *mut OrtAllocator, p: *mut c_void)>, pub Info: Option<unsafe extern "C" fn(this_: *const OrtAllocator) -> *const OrtMemoryInfo>, pub Reserve: Option<unsafe extern "C" fn(this_: *mut OrtAllocator, size: usize) -> *mut c_void>, }
\brief Memory allocation interface

Structure of function pointers that defines a memory allocator. This can be created and filled in by the user for custom allocators.

When an allocator is passed to any function, be sure that the allocator object is not destroyed until the last allocated object using it is freed.

Fields

version: u32

< Must be initialized to ORT_API_VERSION

Alloc: Option<unsafe extern "C" fn(this_: *mut OrtAllocator, size: usize) -> *mut c_void>

< Returns a pointer to an allocated block of size bytes

Free: Option<unsafe extern "C" fn(this_: *mut OrtAllocator, p: *mut c_void)>

< Free a block of memory previously allocated with OrtAllocator::Alloc

Info: Option<unsafe extern "C" fn(this_: *const OrtAllocator) -> *const OrtMemoryInfo>

< Return a pointer to an ::OrtMemoryInfo that describes this allocator

Reserve: Option<unsafe extern "C" fn(this_: *mut OrtAllocator, size: usize) -> *mut c_void>

< Returns a pointer to an allocated block of size bytes