pub type RunAsyncCallbackFn = Option<unsafe extern "C" fn(user_data: *mut c_void, outputs: *mut *mut OrtValue, num_outputs: usize, status: OrtStatusPtr)>;Expand description
\brief Callback function for RunAsync
\param[in] user_data User specific data that passed back to the callback \param[out] outputs On succeed, outputs host inference results, on error, the value will be nullptr \param[out] num_outputs Number of outputs, on error, the value will be zero \param[out] status On error, status will provide details
Aliased Type
enum RunAsyncCallbackFn {
None,
Some(unsafe extern "C" fn(_: *mut c_void, _: *mut *mut OrtValue, _: usize, _: *mut OrtStatus)),
}